﻿using Newtonsoft.Json;
using RetSoft.Demo.Desktop.Models;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Security.Cryptography;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RetSoft.Demo.Desktop
{
    public partial class FolderDemo : Form
    {
        private readonly HttpClient client;

        public FolderDemo(HttpClient client)
        {
            InitializeComponent();
            this.client = client;
        }

        private async void btnGetAll_Click(object sender, EventArgs e)
        {
            var response = await client.GetAsync("api/folders");
            response.EnsureSuccessStatusCode();
            var result = await response.Content.ReadAsJsonAsync<List<FolderModel>>();

            listViewFolders.Items.Clear();
            foreach (var item in result)
            {
                var li = new ListViewItem(item.Id.ToString());
                li.SubItems.Add(item.Name);
                listViewFolders.Items.Add(li);
            }
        }

        private async void btnDelete_Click(object sender, EventArgs e)
        {

            if (listViewFolders.SelectedItems.Count == 0)
                return;

            var folderId = int.Parse(listViewFolders.SelectedItems[0].Text);
            var folderName = listViewFolders.SelectedItems[0].SubItems[1].Text;

            if (MessageBox.Show($"Do you really want to delete '{folderName}'?", "Delete", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                // Delete folder 
                var result = await client.DeleteAsync($"api/folders/{folderId}");
                result.EnsureSuccessStatusCode();
            }
        }

        private async void btnCreate_Click(object sender, EventArgs e)
        {
            var name = NameForm.GetName();
            if (name == null)
                return; // Canceled

            // Create request
            var request = new CreateFolderRequest()
            {
                Name = name,
                Notes = "Demo Folder",
            };
            // Send request
            var response = await client.PostAsJsonAsync("api/folders", request);
            response.EnsureSuccessStatusCode();
        }

        private async void btnRename_Click(object sender, EventArgs e)
        {
            if (listViewFolders.SelectedItems.Count == 0)
                return;

            var name = NameForm.GetName(listViewFolders.SelectedItems[0].SubItems[1].Text);
            if (name == null)
                return; // Canceled

            var folderId = int.Parse(listViewFolders.SelectedItems[0].Text);
            var request = new UpdateFolderRequest
            {
                Name = name
            };

            var response = await client.PutAsJsonAsync($"api/folders/{folderId}", request);
            response.EnsureSuccessStatusCode();
        }
    }
}
