﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;

namespace RetSoft.Demo.Desktop
{
        public static class HttpClientExtensions
        {
            public static Task<HttpResponseMessage> PostAsJsonAsync(this HttpClient client, string requestUri, object content)
            {
                var httpContent = new StringContent(JsonConvert.SerializeObject(content), System.Text.Encoding.UTF8, "application/json");
                return client.PostAsync(requestUri, httpContent);
            }
            public static Task<HttpResponseMessage> PutAsJsonAsync(this HttpClient client, string requestUri, object content)
            {
                var httpContent = new StringContent(JsonConvert.SerializeObject(content), System.Text.Encoding.UTF8, "application/json");
                return client.PutAsync(requestUri, httpContent);
            }

            private static ByteArrayContent ToByteArrayContent(object content)
            {
                var json = JsonConvert.SerializeObject(content);
                var buffer = Encoding.UTF8.GetBytes(json);
                var result = new ByteArrayContent(buffer);
                result.Headers.ContentType = new System.Net.Http.Headers.MediaTypeHeaderValue("application/json");
                return result;
            }

            public static Task<HttpResponseMessage> PutAsByteArrayAsync(this HttpClient client, string requestUri, object content)
            {
                return client.PutAsync(requestUri, ToByteArrayContent(content));
            }

            public static Task<HttpResponseMessage> PostAsByteArrayAsync(this HttpClient client, string requestUri, object content)
            {
                return client.PostAsync(requestUri, ToByteArrayContent(content));
            }

            public async static Task<T> ReadAsJsonAsync<T>(this HttpContent response)
            {
                using (var streamReader = new StreamReader(await response.ReadAsStreamAsync()))
                {
                    var jsonReader = new JsonTextReader(streamReader);
                    var s = new JsonSerializer();
                    return s.Deserialize<T>(jsonReader);
                }
            }
        }
}
